@@ -12,6 +12,7 @@ import java.net.*;
 import java.io.*;
 import java.nio.charset.*;
 import paraselene.*;
+import paraselene.tag.*;
 import paraselene.dyna.*;
 import paraselene.dyna.mockup.*;
 
@@ -167,6 +168,10 @@ public enum Param {
 		"出力文字コードは、" + SOURCE_ENCODE.key + " の指定に従い、\n" +
 		"出力改行コードは、" + SOURCE_LINE.key + " の指定に従います。",
 		false, true ),
+	IGNORE_TAG_ACCESSER( "-ignore_tag_accesser",
+		"name があっても、get/setアクセッサを生成しないタグを指定します。\n" +
+		"指定例) meta param",
+		false, false ),
 	PARAM_URI( "-uri_param_name",
 		"<PARAM>タグでURIを示すname(大文字小文字を同一視します)を指定します。\n" +
 		"指定されたname属性値が一致した場合、対応するvalue属性値を\n" +
@@ -189,7 +194,7 @@ public enum Param {
 		INCLUDE.key + " 指定より優先されます。\n" +
 		"静的コンテンツ扱いになるので " + OTHER.key + " の対象となります。",
 		false, false  ),
-	IGNORE( "-ignore_dir",
+	IGNORE_DIR( "-ignore_dir",
 		"指定したディレクトリ下のファイルを全て無視します。\n" +
 		"HTMLファイルであってもスケルトンソースを生成しませんし、\n" +
 		"excludeディレクトリにも格納されず、完全に無視します。\n" +
@@ -204,6 +209,7 @@ public enum Param {
 	ArrayList<String>	data = new ArrayList<String>();
 	static GrantTagProvider[]	provider = null;
 	static URIPreProcess	uri_pp = null;
+	public static final String SITE = "http://paraselene.sourceforge.jp/";
 
 	public String get() {
 		return getData( 0 );
@@ -251,11 +257,23 @@ public enum Param {
 		return null;
 	}
 
-	static void setParam( String[] input ) {
-		if ( input.length == 0 )	help();
+	private static int	param_cnt = 0;
 
+	static void helpParam( String[] input ) {
+		for ( int i = 0; i < input.length; i++ ) {
+			if ( input[i].equals( "--help" ) ) {
+				help();
+			}
+		}
+	}
+
+	static void setParam( String[] input ) throws Exception {
 		Param	crt = null;
 		for ( int i = 0; i < input.length; i++ ) {
+			if ( input[i].charAt( 0 ) == '@' ) {
+				Config.load( new File( input[i].substring( 1 ) ) );
+				continue;
+			}
 			if ( input[i].charAt( 0 ) == '-' ) {
 				crt = getParam( input[i] );
 				if ( crt == null ) {
@@ -270,7 +288,12 @@ public enum Param {
 				crt.data = new ArrayList<String>();
 			}
 			crt.data.add( input[i] );
+			param_cnt++;
 		}
+	}
+
+	static void loadParam() {
+		if ( param_cnt < 1 )	help();
 
 		Param[] param = values();
 		boolean	exit_f = false;
@@ -395,8 +418,17 @@ public enum Param {
 
 	private static void help() {
 		Param[]	param = values();
-		Linker.readme.echoln( "以下のオプションがあります。\n" +
-			"複数指定可のオプションは、指定したパラメータ全てが追加されていきます。\n" +
+		Linker.readme.echoln(
+			"オプションはテキストファイルに記載して渡す事も可能です。" +
+			"@ファイル名 で読み込みます。\n" +
+			"また、カレントディレクトリに " + Config.CONFIG + " があれば、" +
+			"それを自動的に読み込みます。\n" +
+			"コマンドに直接渡したものは、" + Config.CONFIG + " の内容を上書きします。\n" +
+			"@ファイル名を指定した場合も、それ以降に直接パラメータを指定したものは上書きします。\n" +
+			"テキストファイルにて、パラメータ値に空白を含むものは \" か ' で括って下さい。\n\n" +
+			"--help を指定すると、このヘルプを表示します。\n\n" +
+			"このコマンドには、以下のオプションがあります。\n" +
+			"複数指定可なオプションは、指定したパラメータ全てが追加されていきます。\n" +
 			"複数指定できないオプションは、最後に指定したもの１つが有効になります。\n"
 		);
 		for ( int i = 0; i < param.length; i++ ) {
@@ -460,10 +492,18 @@ public enum Param {
 		return false;
 	}
 
-	static boolean isIgnore( String dir ) {
-		int ex_cnt = IGNORE.data.size();
+	static boolean isIgnoreDir( String dir ) {
+		int ex_cnt = IGNORE_DIR.data.size();
 		for ( int i = 0; i < ex_cnt; i++ ) {
-			if ( isHit( dir, IGNORE.data.get( i ) ) )	return true;
+			if ( isHit( dir, IGNORE_DIR.data.get( i ) ) )	return true;
+		}
+		return false;
+	}
+
+	static boolean isIgnoreTagAccesser( Tag t ) {
+		int	tag_cnt = IGNORE_TAG_ACCESSER.data.size();
+		for ( int i = 0; i < tag_cnt; i++ ) {
+			if ( IGNORE_TAG_ACCESSER.data.get( i ).equalsIgnoreCase( t.getName() ) )	return true;
 		}
 		return false;
 	}
